==> QupZilla-2.2.4.tar.xz: QupZilla-2.2.4/src/plugins/FlashCookieManager/translations/lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
<context>
    <name>FCM_Dialog</name>
    <message>
        <location filename="../fcm_dialog.ui" line="14"/>
        <source>Flash Cookies</source>
        <translation>Flash slapukai</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="24"/>
        <source>Stored Flash Cookies</source>
        <translation>Laikomi Flash slapukai</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="45"/>
        <source>Find: </source>
        <translation>Rasti:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="73"/>
        <location filename="../fcm_dialog.ui" line="120"/>
        <location filename="../fcm_dialog.ui" line="130"/>
        <location filename="../fcm_dialog.ui" line="140"/>
        <location filename="../fcm_dialog.ui" line="256"/>
        <location filename="../fcm_dialog.cpp" line="151"/>
        <location filename="../fcm_dialog.cpp" line="152"/>
        <location filename="../fcm_dialog.cpp" line="153"/>
        <location filename="../fcm_dialog.cpp" line="154"/>
        <source>&lt;flash cookie not selected&gt;</source>
        <translation>&lt;nepasirinktas flash slapukas&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="83"/>
        <source>Last Modified:</source>
        <translation>Keista:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="96"/>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="106"/>
        <source>Size:</source>
        <translation>Dydis:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="113"/>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <source>Origin:</source>
        <translation>Kilmė:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="152"/>
        <source>Extracted latin1 strings:</source>
        <translation>Išskleistos latin1 eilutės:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="182"/>
        <source>These flash cookies are stored on your computer:</source>
        <translation>Šie flash slapukai yra laikomi jūsų kompiuteryje:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="202"/>
        <source>Origin</source>
        <translation>Kilmė</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="227"/>
        <source>Reload from disk</source>
        <translation>Iš naujo įkelti iš disko</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="240"/>
        <source>Path:</source>
        <translation>Kelias:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="253"/>
        <source>Click to open containing folder</source>
        <translation>Spustelėkite, norėdami atverti vidinį aplanką</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="276"/>
        <source>Remove all flash cookies</source>
        <translation>Šalinti visus flash slapukus</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="283"/>
        <location filename="../fcm_dialog.cpp" line="156"/>
        <source>Remove flash cookies</source>
        <translation>Šalinti flash slapukus</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="308"/>
        <source>Flash Cookies Filtering</source>
        <translation>Flash slapukų filtravimas</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="316"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie whitelist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash slapukų baltasis sąrašas&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="348"/>
        <location filename="../fcm_dialog.ui" line="416"/>
        <source>Remove</source>
        <translation>Šalinti</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="355"/>
        <location filename="../fcm_dialog.ui" line="423"/>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="364"/>
        <source>Flash cookies from these origins will not be deleted automatically. (Also detection of them will not be notified to user.)</source>
        <translation>Šių kilmių flash slapukai nebus automatiškai ištrinami. (Be to, naudotojui nebus pranešama apie jų aptikimą.)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="374"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie blacklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash slapukų juodasis sąrašas&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="381"/>
        <source>Flash cookies from these origins will be deleted without any notification.</source>
        <translation>Šių kilmių flash slapukai bus automatiškai ištrinami be jokio pranešimo.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="442"/>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="453"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Cookie Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Slapukų Nustatymai&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="475"/>
        <source>Auto mode: The flash data directory will be checked regularly. and flash cookies in blacklist will be deleted automatically.</source>
        <translation>Automatinė veiksena: Flash duomenų katalogas bus reguliariai tikrinamas, o juodajame sąraše esantys slapukai bus automatiškai ištrinami.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="510"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; This settings are just applied to flash cookies, to manage HTTP cookies use &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies Manager&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pastaba:&lt;/span&gt; Šie nustatymai yra taikomi tik flash slapukams, norėdami tvarkyti HTTP slapukus, naudokite &lt;span style=&quot; font-weight:600;&quot;&gt;Slapukų tvarkytuvę&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="538"/>
        <source>Notification: User will be notified for every new flash cookie that is not in blacklist and whitelist.</source>
        <translation>Pranešimai: Naudotojui bus pranešta apie kiekvieną flash slapuką, kurio nėra juodajame ir baltajame sąraše.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="565"/>
        <source>Delete all flash cookies on exit/start. (except those are in whitelist)</source>
        <translation>Išeinant/paleidžiant ištrinti visus flash slapukus. (išskyrus tuos, kurie baltajame sąraše)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="76"/>
        <source>Search</source>
        <translation>Ieškoti</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="93"/>
        <source>Confirmation</source>
        <translation>Patvirtinimas</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="94"/>
        <source>Are you sure you want to delete all flash cookies on your computer?</source>
        <translation>Ar tikrai norite ištrinti visus, kompiuteryje esančius, flash slapukus?</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="166"/>
        <location filename="../fcm_dialog.cpp" line="237"/>
        <source> (settings)</source>
        <translation> (nustatymai)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="169"/>
        <source> Byte</source>
        <translation>Baitų</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="175"/>
        <source>Remove flash cookie</source>
        <translation>Šalinti flash slapuką</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="241"/>
        <source> [new]</source>
        <translation>[naujas]</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="375"/>
        <source>Add to whitelist</source>
        <translation>Įtraukti į baltąjį sąrašą</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>Already whitelisted!</source>
        <translation>Jau yra baltajame sąraše!</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <source>The server &quot;%1&quot; is already in blacklist, please remove it first.</source>
        <translation>Serveris &quot;%1&quot; jau yra juodajame sąraše, prašome, iš pradžių, jį pašalinti.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <location filename="../fcm_dialog.cpp" line="374"/>
        <source>Add to blacklist</source>
        <translation>Įtraukti į juodąjį sąrašą</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>The origin &quot;%1&quot; is already in whitelist, please remove it first.</source>
        <translation>Šaltinis &quot;%1&quot; jau yra baltajame sąraše, prašome, iš pradžių, jį pašalinti.</translation>
    </message>
</context>
<context>
    <name>FCM_Notification</name>
    <message>
        <location filename="../fcm_notification.ui" line="45"/>
        <source>New flash cookie was detected!</source>
        <translation>Buvo aptiktas naujas flash slapukas!</translation>
    </message>
    <message>
        <location filename="../fcm_notification.ui" line="52"/>
        <source>View</source>
        <translation>Žiūrėti</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="34"/>
        <source>A new flash cookie was detected</source>
        <translation>Buvo aptiktas naujas flash slapukas</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="37"/>
        <source>%1 new flash cookies were detected</source>
        <translation>Buvo aptikta %1 naujų flash slapukų</translation>
    </message>
</context>
<context>
    <name>FCM_Plugin</name>
    <message>
        <location filename="../fcm_plugin.cpp" line="129"/>
        <source>Flash Cookie Manager</source>
        <translation>Flash slapukų tvarkytuvė</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="357"/>
        <source>Show Flash Cookie Manager</source>
        <translation>Rodyti Flash slapukų tvarkytuvę</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="439"/>
        <source>!default</source>
        <translation>!numatytoji</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="451"/>
        <source>!other</source>
        <translation>!kita</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.6.tar.xz: QupZilla-2.2.6/src/plugins/FlashCookieManager/translations/lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
<context>
    <name>FCM_Button</name>
    <message>
        <location filename="../fcm_plugin.cpp" line="58"/>
        <source>Flash Cookie Manager button</source>
        <translation>Flash slapukų tvarkytuvės mygtukas</translation>
    </message>
</context>
<context>
    <name>FCM_Dialog</name>
    <message>
        <location filename="../fcm_dialog.ui" line="14"/>
        <source>Flash Cookies</source>
        <translation>Flash slapukai</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="24"/>
        <source>Stored Flash Cookies</source>
        <translation>Laikomi Flash slapukai</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="45"/>
        <source>Find: </source>
        <translation>Rasti:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="73"/>
        <location filename="../fcm_dialog.ui" line="120"/>
        <location filename="../fcm_dialog.ui" line="130"/>
        <location filename="../fcm_dialog.ui" line="140"/>
        <location filename="../fcm_dialog.ui" line="256"/>
        <location filename="../fcm_dialog.cpp" line="151"/>
        <location filename="../fcm_dialog.cpp" line="152"/>
        <location filename="../fcm_dialog.cpp" line="153"/>
        <location filename="../fcm_dialog.cpp" line="154"/>
        <source>&lt;flash cookie not selected&gt;</source>
        <translation>&lt;nepasirinktas flash slapukas&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="83"/>
        <source>Last Modified:</source>
        <translation>Keista:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="96"/>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="106"/>
        <source>Size:</source>
        <translation>Dydis:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="113"/>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <source>Origin:</source>
        <translation>Kilmė:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="152"/>
        <source>Extracted latin1 strings:</source>
        <translation>Išskleistos latin1 eilutės:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="182"/>
        <source>These flash cookies are stored on your computer:</source>
        <translation>Šie flash slapukai yra laikomi jūsų kompiuteryje:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="202"/>
        <source>Origin</source>
        <translation>Kilmė</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="227"/>
        <source>Reload from disk</source>
        <translation>Iš naujo įkelti iš disko</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="240"/>
        <source>Path:</source>
        <translation>Kelias:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="253"/>
        <source>Click to open containing folder</source>
        <translation>Spustelėkite, norėdami atverti vidinį aplanką</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="276"/>
        <source>Remove all flash cookies</source>
        <translation>Šalinti visus flash slapukus</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="283"/>
        <location filename="../fcm_dialog.cpp" line="156"/>
        <source>Remove flash cookies</source>
        <translation>Šalinti flash slapukus</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="308"/>
        <source>Flash Cookies Filtering</source>
        <translation>Flash slapukų filtravimas</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="316"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie whitelist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash slapukų baltasis sąrašas&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="348"/>
        <location filename="../fcm_dialog.ui" line="416"/>
        <source>Remove</source>
        <translation>Šalinti</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="355"/>
        <location filename="../fcm_dialog.ui" line="423"/>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="364"/>
        <source>Flash cookies from these origins will not be deleted automatically. (Also detection of them will not be notified to user.)</source>
        <translation>Šių kilmių flash slapukai nebus automatiškai ištrinami. (Be to, naudotojui nebus pranešama apie jų aptikimą.)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="374"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie blacklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash slapukų juodasis sąrašas&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="381"/>
        <source>Flash cookies from these origins will be deleted without any notification.</source>
        <translation>Šių kilmių flash slapukai bus automatiškai ištrinami be jokio pranešimo.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="442"/>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="453"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Cookie Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Slapukų Nustatymai&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="475"/>
        <source>Auto mode: The flash data directory will be checked regularly. and flash cookies in blacklist will be deleted automatically.</source>
        <translation>Automatinė veiksena: Flash duomenų katalogas bus reguliariai tikrinamas, o juodajame sąraše esantys slapukai bus automatiškai ištrinami.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="510"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; This settings are just applied to flash cookies, to manage HTTP cookies use &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies Manager&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pastaba:&lt;/span&gt; Šie nustatymai yra taikomi tik flash slapukams, norėdami tvarkyti HTTP slapukus, naudokite &lt;span style=&quot; font-weight:600;&quot;&gt;Slapukų tvarkytuvę&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="538"/>
        <source>Notification: User will be notified for every new flash cookie that is not in blacklist and whitelist.</source>
        <translation>Pranešimai: Naudotojui bus pranešta apie kiekvieną flash slapuką, kurio nėra juodajame ir baltajame sąraše.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="565"/>
        <source>Delete all flash cookies on exit/start. (except those are in whitelist)</source>
        <translation>Išeinant/paleidžiant ištrinti visus flash slapukus. (išskyrus tuos, kurie baltajame sąraše)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="76"/>
        <source>Search</source>
        <translation>Ieškoti</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="93"/>
        <source>Confirmation</source>
        <translation>Patvirtinimas</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="94"/>
        <source>Are you sure you want to delete all flash cookies on your computer?</source>
        <translation>Ar tikrai norite ištrinti visus, kompiuteryje esančius, flash slapukus?</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="166"/>
        <location filename="../fcm_dialog.cpp" line="237"/>
        <source> (settings)</source>
        <translation> (nustatymai)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="169"/>
        <source> Byte</source>
        <translation>Baitų</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="175"/>
        <source>Remove flash cookie</source>
        <translation>Šalinti flash slapuką</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="241"/>
        <source> [new]</source>
        <translation>[naujas]</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="375"/>
        <source>Add to whitelist</source>
        <translation>Įtraukti į baltąjį sąrašą</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>Already whitelisted!</source>
        <translation>Jau yra baltajame sąraše!</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <source>The server &quot;%1&quot; is already in blacklist, please remove it first.</source>
        <translation>Serveris &quot;%1&quot; jau yra juodajame sąraše, prašome, iš pradžių, jį pašalinti.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <location filename="../fcm_dialog.cpp" line="374"/>
        <source>Add to blacklist</source>
        <translation>Įtraukti į juodąjį sąrašą</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>The origin &quot;%1&quot; is already in whitelist, please remove it first.</source>
        <translation>Šaltinis &quot;%1&quot; jau yra baltajame sąraše, prašome, iš pradžių, jį pašalinti.</translation>
    </message>
</context>
<context>
    <name>FCM_Notification</name>
    <message>
        <location filename="../fcm_notification.ui" line="45"/>
        <source>New flash cookie was detected!</source>
        <translation>Buvo aptiktas naujas flash slapukas!</translation>
    </message>
    <message>
        <location filename="../fcm_notification.ui" line="52"/>
        <source>View</source>
        <translation>Žiūrėti</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="34"/>
        <source>A new flash cookie was detected</source>
        <translation>Buvo aptiktas naujas flash slapukas</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="37"/>
        <source>%1 new flash cookies were detected</source>
        <translation>Buvo aptikta %1 naujų flash slapukų</translation>
    </message>
</context>
<context>
    <name>FCM_Plugin</name>
    <message>
        <location filename="../fcm_plugin.cpp" line="147"/>
        <location filename="../fcm_plugin.cpp" line="377"/>
        <source>Flash Cookie Manager</source>
        <translation>Flash slapukų tvarkytuvė</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="378"/>
        <source>Show Flash Cookie Manager</source>
        <translation>Rodyti Flash slapukų tvarkytuvę</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="459"/>
        <source>!default</source>
        <translation>!numatytoji</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="471"/>
        <source>!other</source>
        <translation>!kita</translation>
    </message>
</context>
</TS>
